@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"math"
 	"os"
+	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
 )
@@ -14,13 +15,26 @@ type linter struct {
 
 func (l *linter) lint(check rule.Rule) {
 	// crashout immediately if there is a check with no id
-	if check.ID == "" {
-		fmt.Printf("Found a check with no ID\n")
+	if check.ShortCode == "" {
+		fmt.Printf("%s: Found a check with no short code\n", check.ID())
 		os.Exit(1)
 	}
+	if check.Service == "" {
+		fmt.Printf("%s: Found a check with no service\n", check.ID())
+		os.Exit(1)
+	}
+	if check.Provider == "" {
+		fmt.Printf("%s: Found a check with no provider\n", check.ID())
+		os.Exit(1)
+	}
+	if len(check.Documentation.Links) == 0 {
+		fmt.Printf("%s: Found check with no links\n", check.ID())
+		os.Exit(1)
+	}
+
 	errorFound := l.checkDocumentation(check)
 	if len(check.RequiredTypes) == 0 {
-		fmt.Printf("%s: missing required types\n", check.ID)
+		fmt.Printf("%s: missing required types\n", check.ID())
 		errorFound = true
 	}
 
@@ -31,41 +45,46 @@ func (l *linter) lint(check rule.Rule) {
 
 func (l *linter) checkDocumentation(check rule.Rule) bool {
 	docs := check.Documentation
+
 	var errorFound bool
-	if err := l.verifyPart(string(docs.Summary), "Summary"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
-		errorFound = true
-	}
-	if err := l.verifyPart(docs.Impact, "Impact"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
-		errorFound = true
-	}
-	if err := l.verifyPart(docs.Resolution, "Resolution"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
-		errorFound = true
-	}
-	if err := l.verifyPart(docs.Explanation, "Explanation"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
-		errorFound = true
-	}
-	if err := l.verifyPart(docs.GoodExample, "GoodExample"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
-		errorFound = true
-	}
-	if err := l.verifyPart(docs.BadExample, "BadExample"); err != nil {
-		fmt.Printf("%s: %s\n", check.ID, err.Error())
+	if !strings.Contains(check.Documentation.Links[0], ".terraform.io") {
+		fmt.Printf("%s: The first link should be Terraform for consistency\n", check.ID())
 		errorFound = true
 	}
 
+	if err := l.verifyPart(string(docs.Summary), "Summary"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
+	if err := l.verifyPart(docs.Impact, "Impact"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
+	if err := l.verifyPart(docs.Resolution, "Resolution"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
+	if err := l.verifyPart(docs.Explanation, "Explanation"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
+	if err := l.verifyPart(docs.GoodExample, "GoodExample"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
+	if err := l.verifyPart(docs.BadExample, "BadExample"); err != nil {
+		fmt.Printf("%s: %s\n", check.ID(), err.Error())
+		errorFound = true
+	}
 	if len(docs.Links) == 0 {
-		fmt.Printf("%s: Has no links configure\n", check.ID)
+		fmt.Printf("%s: Has no links configure\n", check.ID())
 		errorFound = true
 	}
 	return errorFound
 }
 
 func (l *linter) verifyPart(checkPart, checkDescription string) error {
-	if checkPart == "" {
+	if strings.TrimSpace(checkPart) == "" {
 		return fmt.Errorf("[%s] documentation is empty", checkDescription)
 	}
 
