@@ -55,6 +55,7 @@ var allDirs = false
 var runStatistics bool
 var ignoreHCLErrors bool
 var stopOnCheckError bool
+var workspace string
 
 func init() {
 	rootCmd.Flags().BoolVar(&ignoreHCLErrors, "ignore-hcl-errors", ignoreHCLErrors, "Stop and report an error if an HCL parse error is encountered")
@@ -81,6 +82,7 @@ func init() {
 	rootCmd.Flags().BoolVar(&ignoreWarnings, "ignore-warnings", ignoreWarnings, "[DEPRECATED] Don't show warnings in the output.")
 	rootCmd.Flags().BoolVar(&ignoreInfo, "ignore-info", ignoreWarnings, "[DEPRECATED] Don't show info results in the output.")
 	rootCmd.Flags().BoolVarP(&stopOnCheckError, "allow-checks-to-panic", "p", stopOnCheckError, "Allow panics to propagate up from rule checking")
+	rootCmd.Flags().StringVarP(&workspace, "workspace", "w", workspace, "Specify a workspace for ignore limits")
 }
 
 func main() {
@@ -202,7 +204,7 @@ var rootCmd = &cobra.Command{
 		}
 
 		if len(tfvarsPaths) == 0 && unusedTfvarsPresent(dir) {
-			_ = tml.Printf("\n<yellow>Warning: A tfvars file was found but not automatically used. \nDid you mean to specify the --tfvars-file flag?</yellow>\n")
+			fmt.Fprintf(os.Stderr, "Warning: A tfvars file was found but not automatically used. Did you mean to specify the --tfvars-file flag?\n")
 		}
 
 		debug.Log("Starting parser...")
@@ -287,6 +289,11 @@ func getParserOptions() []parser.Option {
 	if !ignoreHCLErrors {
 		opts = append(opts, parser.OptionStopOnHCLError())
 	}
+
+	if workspace != "" {
+		opts = append(opts, parser.OptionWithWorkspaceName(workspace))
+	}
+
 	return opts
 }
 
@@ -352,6 +359,9 @@ func getScannerOptions() []scanner.Option {
 	if includeIgnored {
 		options = append(options, scanner.OptionIncludeIgnored())
 	}
+	if workspace != "" {
+		options = append(options, scanner.OptionWithWorkspaceName(workspace))
+	}
 
 	options = append(options, scanner.OptionIgnoreCheckErrors(!stopOnCheckError))
 
