@@ -25,6 +25,7 @@ type Scanner struct {
 	includeIgnored    bool
 	excludedRuleIDs   []string
 	ignoreCheckErrors bool
+	workspaceName     string
 }
 
 // New creates a new Scanner
@@ -39,10 +40,9 @@ func New(options ...Option) *Scanner {
 }
 
 // Find element in list
-func checkInList(id string, list []string) bool {
-	codeCurrent := string(id)
+func checkInList(id string, legacyID string, list []string) bool {
 	for _, codeIgnored := range list {
-		if codeIgnored == codeCurrent {
+		if codeIgnored == id || codeIgnored == legacyID {
 			return true
 		}
 	}
@@ -64,11 +64,12 @@ func (scanner *Scanner) Scan(blocks []block.Block) []result.Result {
 		for _, r := range rules {
 			func(r *rule.Rule) {
 				if rule.IsRuleRequiredForBlock(r, checkBlock) {
-					debug.Log("Running rule for %s on %s.%s (%s)...", r.ID, checkBlock.Type(), checkBlock.FullName(), checkBlock.Range().Filename)
+					debug.Log("Running rule for %s on %s (%s)...", r.ID(), checkBlock.Reference(), checkBlock.Range().Filename)
 					ruleResults := rule.CheckRule(r, checkBlock, context, scanner.ignoreCheckErrors)
 					if scanner.includePassed && ruleResults.All() == nil {
 						res := result.New(checkBlock).
-							WithRuleID(r.ID).
+							WithLegacyRuleID(r.LegacyID).
+							WithRuleID(r.ID()).
 							WithDescription(fmt.Sprintf("Resource '%s' passed check: %s", checkBlock.FullName(), r.Documentation.Summary)).
 							WithRange(checkBlock.Range()).
 							WithStatus(result.Passed).
@@ -81,12 +82,13 @@ func (scanner *Scanner) Scan(blocks []block.Block) []result.Result {
 							if ruleResult.Severity == severity.None {
 								ruleResult.Severity = r.DefaultSeverity
 							}
-							if scanner.includeIgnored || (!scanner.checkRangeIgnored(ruleResult.RuleID, ruleResult.Range, checkBlock) && !checkInList(ruleResult.RuleID, scanner.excludedRuleIDs)) {
-								results = append(results, ruleResult)
-							} else {
+							if !scanner.includeIgnored && (scanner.checkRangeIgnored(ruleResult.RuleID, ruleResult.Range, checkBlock) || scanner.checkRangeIgnored(ruleResult.LegacyRuleID, ruleResult.Range, checkBlock) || checkInList(ruleResult.RuleID, ruleResult.LegacyRuleID, scanner.excludedRuleIDs)) {
 								// rule was ignored
 								metrics.Add(metrics.IgnoredChecks, 1)
-								debug.Log("Ignoring '%s' based on tfsec:ignore statement", ruleResult.RuleID)
+								debug.Log("Ignoring '%s'", ruleResult.RuleID)
+							} else {
+								results = append(results, ruleResult)
+
 							}
 						}
 					}
@@ -103,7 +105,7 @@ func readLines(filename string) ([]string, error) {
 		return nil, err
 	}
 
-	return append([]string{""}, strings.Split(string(raw), "\n")...), nil
+	return append([]string{""}, strings.Split(strings.ReplaceAll(string(raw), "\r", ""), "\n")...), nil
 }
 
 func (scanner *Scanner) checkRangeIgnored(id string, r block.Range, b block.Block) bool {
@@ -152,12 +154,44 @@ func (scanner *Scanner) checkRangeIgnored(id string, r block.Range, b block.Bloc
 	}
 
 	if foundValidIgnore {
-		return isIgnoreWithinExpiry(ignoreLine, id, b.Range())
+		return scanner.verifyIgnoreConditions(ignoreLine, id, b)
 	}
 
 	return foundValidIgnore
 }
 
+func (scanner *Scanner) verifyIgnoreConditions(ignoreLine string, id string, b block.Block) bool {
+	for _, ignoreCode := range strings.Split(ignoreLine, " ") {
+		ignoreCode = fmt.Sprintf("%s:", ignoreCode)
+		if strings.Contains(ignoreCode, fmt.Sprintf("%s:", id)) || strings.Contains(ignoreCode, "ignore:*") {
+			if scanner.workspaceName != "" && strings.Contains(ignoreCode, ":ws:") {
+				if isIgnoreWithinExpiry(ignoreCode, id, b.Range()) {
+					if scanner.isWorkspaceIgnored(ignoreCode, id, b.Range()) {
+						return true
+					} else {
+						return false
+					}
+				}
+			} else {
+				return isIgnoreWithinExpiry(ignoreCode, id, b.Range())
+			}
+		}
+	}
+	return false
+}
+
+func (s *Scanner) isWorkspaceIgnored(ignoreLine string, id string, r block.Range) bool {
+	ignoreLine = fmt.Sprintf("%s:", ignoreLine)
+	if strings.Contains(ignoreLine, ":ws:") {
+		if s.workspaceName == "" {
+			return false
+		}
+		return strings.Contains(ignoreLine, fmt.Sprintf(":ws:%s:", s.workspaceName))
+	}
+
+	return false
+}
+
 func isIgnoreWithinExpiry(ignoreLine string, id string, r block.Range) bool {
 	expWithCode := fmt.Sprintf("%s:exp:", id)
 	if indexExpFound := strings.Index(ignoreLine, expWithCode); indexExpFound > 0 {
