@@ -6,13 +6,16 @@ import "strings"
 type Provider string
 
 const (
+	UnknownProvider      Provider = ""
 	AWSProvider          Provider = "aws"
 	AzureProvider        Provider = "azure"
-	GCPProvider          Provider = "google"
-	GeneralProvider      Provider = "general"
-	OracleProvider       Provider = "oracle"
-	DigitalOceanProvider Provider = "digitalocean"
 	CustomProvider       Provider = "custom"
+	DigitalOceanProvider Provider = "digitalocean"
+	GeneralProvider      Provider = "general"
+	GitHubProvider       Provider = "github"
+	GoogleProvider       Provider = "google"
+	OracleProvider       Provider = "oracle"
+	OpenStackProvider    Provider = "openstack"
 )
 
 func RuleProviderToString(provider Provider) string {
