@@ -15,6 +15,7 @@ import (
 // by, a human-readable description and a range
 type Result struct {
 	RuleID          string            `json:"rule_id"`
+	LegacyRuleID    string            `json:"legacy_rule_id"`
 	RuleSummary     string            `json:"rule_description"`
 	RuleProvider    provider.Provider `json:"rule_provider"`
 	Impact          string            `json:"impact"`
@@ -40,6 +41,7 @@ func New(resourceBlock block.Block) *Result {
 	return &Result{
 		Status:        Failed,
 		topLevelBlock: resourceBlock,
+		Range:         resourceBlock.Range(),
 	}
 }
 
@@ -60,6 +62,11 @@ func (r *Result) WithRuleID(id string) *Result {
 	return r
 }
 
+func (r *Result) WithLegacyRuleID(id string) *Result {
+	r.LegacyRuleID = id
+	return r
+}
+
 func (r *Result) WithRuleSummary(description string) *Result {
 	r.RuleSummary = description
 	return r
@@ -118,6 +125,8 @@ func (r *Result) WithAttributeAnnotation(attr block.Attribute) *Result {
 
 	typ := attr.Type()
 
+	r.WithRange(attr.Range())
+
 	switch typ {
 	case cty.String:
 		raw = fmt.Sprintf("%q", attr.Value().AsString())
